Replace all uses iree-translate with iree-compile

Replace iree-translate with iree-compile to accommodate upstream API
change.

Change-Id: Ia75ca5f214869c8c7ceac55220caf4a88b584572
diff --git a/cmake/springbok_modules.cmake b/cmake/springbok_modules.cmake
index 30d3a40..d83be9e 100644
--- a/cmake/springbok_modules.cmake
+++ b/cmake/springbok_modules.cmake
@@ -2,7 +2,7 @@
 
 # springbok_modules()
 #
-# A wrapper for the springbok_bytecode_module and springbok_c_module to apply common iree-translate flags
+# A wrapper for the springbok_bytecode_module and springbok_c_module to apply common iree-compile flags
 # Parameters:
 # NAME: Name of target.
 # SRC: Source file to compile into a bytecode module. Support relative path.
diff --git a/samples/float_model/CMakeLists.txt b/samples/float_model/CMakeLists.txt
index b673962..d89bcc9 100644
--- a/samples/float_model/CMakeLists.txt
+++ b/samples/float_model/CMakeLists.txt
@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# Build the mlir bytecode modules with iree-translate. Note the last two flags
+# Build the mlir bytecode modules with iree-compile. Note the last two flags
 # are for RVV support.
 #-------------------------------------------------------------------------------
 
diff --git a/samples/quant_model/CMakeLists.txt b/samples/quant_model/CMakeLists.txt
index fec246e..d7316db 100644
--- a/samples/quant_model/CMakeLists.txt
+++ b/samples/quant_model/CMakeLists.txt
@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# Build the mlir bytecode modules with iree-translate. Note the last two flags
+# Build the mlir bytecode modules with iree-compile. Note the last two flags
 # are for RVV support.
 #-------------------------------------------------------------------------------
 
diff --git a/samples/simple_vec_mul/CMakeLists.txt b/samples/simple_vec_mul/CMakeLists.txt
index 661032a..17bbc2f 100644
--- a/samples/simple_vec_mul/CMakeLists.txt
+++ b/samples/simple_vec_mul/CMakeLists.txt
@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# Build the mlir bytecode modules with iree-translate. Note the last two flags
+# Build the mlir bytecode modules with iree-compile. Note the last two flags
 # are for RVV support.
 # https://github.com/llvm/llvm-project/blob/0eeab8b/llvm/lib/Target/RISCV/RISCVSubtarget.cpp#L30-L51
 #-------------------------------------------------------------------------------
diff --git a/cmake/springbok_bytecode_module.cmake b/cmake/springbok_bytecode_module.cmake
index 05e3ab9..9edf0db 100644
--- a/cmake/springbok_bytecode_module.cmake
+++ b/cmake/springbok_bytecode_module.cmake
@@ -2,7 +2,7 @@
 
 # springbok_bytecode_module()
 #
 # A wrapper for the iree_bytecode_module to apply common iree-translate flags
 # Parameters:
 # NAME: Name of target.
 # SRC: Source file to compile into a bytecode module. Support relative path.
@@ -68,7 +68,7 @@
   endif()
 
   get_filename_component(_MLIR_SRC "${_MLIR_SRC}" REALPATH)
-  iree_get_executable_path(_TRANSLATE_TOOL_EXECUTABLE "iree-translate")
+  iree_get_executable_path(_TRANSLATE_TOOL_EXECUTABLE "iree-compile")
   iree_get_executable_path(_LINKER_TOOL_EXECUTABLE "lld")
 
   # Replace dependencies passed by ::name with iree::package::name
@@ -89,7 +89,7 @@
   endif()
 
   ## Example with VM C module.
   # Setup args for iree-translate.
   set(_TRANSLATE_ARGS ${_RULE_FLAGS})
   list(APPEND _TRANSLATE_ARGS "-iree-mlir-to-vm-bytecode-module")
   list(APPEND _TRANSLATE_ARGS "-iree-hal-target-backends=dylib-llvm-aot")
@@ -105,7 +105,7 @@
   list(APPEND _TRANSLATE_ARGS "-o")
   list(APPEND _TRANSLATE_ARGS "${_VMFB_FILE_NAME}")
 
   # Custom command for iree-translate to generate static library and C module.
   add_custom_command(
     OUTPUT
       ${_H_FILE_NAME}
@@ -2,7 +2,7 @@
 # springbok_bytecode_module()
 #
-# A wrapper for the iree_bytecode_module to apply common iree-translate flags
+# A wrapper for the iree_bytecode_module to apply common iree-compile flags
 # Parameters:
 # NAME: Name of target.
@@ -89,7 +89,7 @@
 
   ## Example with VM C module.
-  # Setup args for iree-translate.
+  # Setup args for iree-compile.
   set(_TRANSLATE_ARGS ${_RULE_FLAGS})
   list(APPEND _TRANSLATE_ARGS "-iree-mlir-to-vm-bytecode-module")
@@ -105,7 +105,7 @@
   list(APPEND _TRANSLATE_ARGS "${_VMFB_FILE_NAME}")
 
-  # Custom command for iree-translate to generate static library and C module.
+  # Custom command for iree-compile to generate static library and C module.
   add_custom_command(
     OUTPUT
diff --git a/cmake/springbok_c_module.cmake b/cmake/springbok_c_module.cmake
index e9774bf..0db52cb 100644
--- a/cmake/springbok_c_module.cmake
+++ b/cmake/springbok_c_module.cmake
@@ -2,7 +2,7 @@
 
 # springbok_c_module()
 #
 # A wrapper for the iree c module to apply common iree-translate flags
 # Parameters:
 # NAME: Name of target.
 # SRC: Source file to compile into an emitC module. Support relative path.
@@ -64,7 +64,7 @@
   endif()
 
   get_filename_component(_MLIR_SRC "${_MLIR_SRC}" REALPATH)
-  iree_get_executable_path(_TRANSLATE_TOOL_EXECUTABLE "iree-translate")
+  iree_get_executable_path(_TRANSLATE_TOOL_EXECUTABLE "iree-compile")
   iree_get_executable_path(_LINKER_TOOL_EXECUTABLE "lld")
 
   # Replace dependencies passed by ::name with iree::package::name
@@ -88,7 +88,7 @@
   endif()
 
   ## Example with VM C module.
   # Setup args for iree-translate.
   set(_TRANSLATE_ARGS ${_RULE_FLAGS})
   list(APPEND _TRANSLATE_ARGS "-iree-mlir-to-vm-c-module")
   list(APPEND _TRANSLATE_ARGS "-iree-hal-target-backends=dylib-llvm-aot")
@@ -104,7 +104,7 @@
   list(APPEND _TRANSLATE_ARGS "-o")
   list(APPEND _TRANSLATE_ARGS "${_EMITC_FILE_NAME}")
 
   # Custom command for iree-translate to generate static library and C module.
   add_custom_command(
     OUTPUT
       ${_H_FILE_NAME}
@@ -2,7 +2,7 @@
 # springbok_c_module()
 #
-# A wrapper for the iree c module to apply common iree-translate flags
+# A wrapper for the iree c module to apply common iree-compile flags
 # Parameters:
 # NAME: Name of target.
@@ -88,7 +88,7 @@
 
   ## Example with VM C module.
-  # Setup args for iree-translate.
+  # Setup args for iree-compile.
   set(_TRANSLATE_ARGS ${_RULE_FLAGS})
   list(APPEND _TRANSLATE_ARGS "-iree-mlir-to-vm-c-module")
@@ -104,7 +104,7 @@
   list(APPEND _TRANSLATE_ARGS "${_EMITC_FILE_NAME}")
 
-  # Custom command for iree-translate to generate static library and C module.
+  # Custom command for iree-compile to generate static library and C module.
   add_custom_command(
     OUTPUT